SystemOrganization addCategory: #'MCFeed-Core'!

!WriteStream methodsFor: '*mcfeed' stamp: 'cwp 7/27/2007 01:47'!
br
	self nextPutAll: '<br />'.
	self nextPut: Character lf! !

!WriteStream methodsFor: '*mcfeed' stamp: 'cwp 7/27/2007 02:01'!
feedContent: aString
	aString do:
		[:char |
		char = $< 
			ifTrue: [self nextPutAll: '&lt;']
			ifFalse: [char = $& 
						ifTrue: [self nextPutAll: '&amp;']
						ifFalse: [char = Character cr
									ifTrue: [self br]
									ifFalse: [self nextPut: char]]]]! !

Object subclass: #MCFeedBuilder
	instanceVariableNames: 'name baseUrl repository feed'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MCFeed-Core'!

!MCFeedBuilder methodsFor: 'accessing' stamp: 'cwp 7/26/2007 23:46'!
baseUrl: aURI
	baseUrl := aURI! !

!MCFeedBuilder methodsFor: 'building' stamp: 'cwp 7/27/2007 00:48'!
build: size
	feed := AtomFeed new.
	self decorateFeed.
	(self last: size versionsFrom: repository)
		 do: [:ea | feed addEntry: (self entryForVersion: ea)].
	! !

!MCFeedBuilder methodsFor: 'building' stamp: 'cwp 7/27/2007 01:52'!
contentForVersion: aVersion
	^ AtomTextHTML new
		text: (MCEntryContent version: aVersion repository: repository) text;
		yourself! !

!MCFeedBuilder methodsFor: 'building' stamp: 'cwp 7/27/2007 00:56'!
decorateFeed
	feed
		id: repository description;
		titleText: name;
		updated: DateAndTime now;
		addLink: self linkForFeed! !

!MCFeedBuilder methodsFor: 'accessing' stamp: 'cwp 7/27/2007 00:39'!
directory: aString
	repository := MCDirectoryRepository new.
	repository directory: (FileDirectory on: aString)! !

!MCFeedBuilder methodsFor: 'building' stamp: 'cwp 7/27/2007 01:49'!
entryForVersion: aVersion
	| entry info |
	info := aVersion info.
	entry := AtomEntry new.
	entry id: 'uuid:', info id asString.
	entry titleText: info name.
	entry updated: (DateAndTime date: info date time: info time)..
	entry addAuthor: (AtomPerson new name: info author).
	entry addLink: (self linkForVersion: aVersion).
	entry summaryText: info message.
	entry content: (self contentForVersion: aVersion).
	^ entry! !

!MCFeedBuilder methodsFor: 'writing' stamp: 'cwp 7/27/2007 00:33'!
feedString
	^ String streamContents: [:stream | self writeFeedOn: stream]! !

!MCFeedBuilder methodsFor: 'building' stamp: 'cwp 7/27/2007 00:45'!
last: anInteger versionsFrom: aRepository
	^ (aRepository allFileNames first: anInteger) 
		collect: [:ea | aRepository versionFromFileNamed: ea]! !

!MCFeedBuilder methodsFor: 'building' stamp: 'cwp 7/27/2007 00:57'!
linkForFeed
	^ AtomLink new
		beAlternate;
		href: baseUrl asString;
		title: name, ' Repository';
		yourself! !

!MCFeedBuilder methodsFor: 'building' stamp: 'cwp 7/26/2007 23:47'!
linkForVersion: aVersion
	^ AtomLink new
		beEnclosure;
		href: (baseUrl resolveRelativeURI: aVersion fileName) asString;
		yourself
		! !

!MCFeedBuilder methodsFor: 'accessing' stamp: 'cwp 7/27/2007 00:44'!
name: aString
	name := aString! !

!MCFeedBuilder methodsFor: 'writing' stamp: 'cwp 7/27/2007 00:33'!
writeFeedOn: aStream 
	aStream nextPutAll: '<?xml version="1.0" encoding="utf-8"?>'.
	^ feed xmlOn: aStream! !

!MCFeedBuilder methodsFor: 'writing' stamp: 'cwp 7/27/2007 00:35'!
writeFeedTo: aString
	| f |
	f := FileStream forceNewFileNamed: aString.
	[self writeFeedOn: f]
		ensure: [f ifNotNil: [f close]]! !

MCVersionNotification subclass: #MCEntryContent
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MCFeed-Core'!

!MCEntryContent methodsFor: 'as yet unclassified' stamp: 'cwp 7/27/2007 01:56'!
printDiff: aModification on: aStream
	| builder |
	builder := TextDiffBuilder 
		from: aModification fromSource 
		to: aModification toSource.
	builder buildPatchSequence do:
		[:assoc |
		assoc key = #insert 
			ifTrue: [aStream nextPutAll: '+ '] 
			ifFalse:
				[assoc key = #remove 
					ifTrue: [aStream nextPutAll: '- '] 
					ifFalse: [aStream nextPutAll: '  ']].
		aStream feedContent: assoc value; br]! !

!MCEntryContent methodsFor: 'as yet unclassified' stamp: 'cwp 7/27/2007 01:59'!
text
	^ String streamContents:
		[:s |
		s feedContent: version summary.
		changes isEmpty ifFalse:
			[s 
				br; br;
				nextPutAll: '-----------------------------------------------------'; br;
				nextPutAll: 'Changes since ';
				feedContent: ancestor info name;
				nextPut: $:; br.
			changes do:
				[:ea |
				s br; feedContent: ea summary; br.
				self printDiff: ea on: s]]]! !
